/**
 * 实体数据服务注册中心
 *
 * @export
 * @class EntityServiceRegister
 */
export class EntityServiceRegister {

    /**
     * 所有实体数据服务Map
     *
     * @protected
     * @type {*}
     * @memberof EntityServiceRegister
     */
    protected allEntityService: Map<string, () => Promise<any>> = new Map();

    /**
     * 已加载实体数据服务Map缓存
     *
     * @protected
     * @type {Map<string, any>}
     * @memberof EntityServiceRegister
     */
    protected serviceCache: Map<string, any> = new Map();

    /**
     * Creates an instance of EntityServiceRegister.
     * @memberof EntityServiceRegister
     */
    constructor() {
        this.init();
    }

    /**
     * 初始化
     *
     * @protected
     * @memberof EntityServiceRegister
     */
    protected init(): void {
                this.allEntityService.set('ibz5sample0005', () => import('@/service/ibz5-sample0005/ibz5-sample0005-service'));
        this.allEntityService.set('ibz5custom', () => import('@/service/ibz5-custom/ibz5-custom-service'));
        this.allEntityService.set('ibz5sample', () => import('@/service/ibz5-sample/ibz5-sample-service'));
        this.allEntityService.set('ibz5supplier', () => import('@/service/ibz5-supplier/ibz5-supplier-service'));
        this.allEntityService.set('ibz5sample0018', () => import('@/service/ibz5-sample0018/ibz5-sample0018-service'));
        this.allEntityService.set('ibz5sample0013', () => import('@/service/ibz5-sample0013/ibz5-sample0013-service'));
        this.allEntityService.set('ibz5sample0001', () => import('@/service/ibz5-sample0001/ibz5-sample0001-service'));
        this.allEntityService.set('ibz5storage', () => import('@/service/ibz5-storage/ibz5-storage-service'));
        this.allEntityService.set('ibz5orderdetail', () => import('@/service/ibz5-order-detail/ibz5-order-detail-service'));
        this.allEntityService.set('ibz5hardware', () => import('@/service/ibz5-hardware/ibz5-hardware-service'));
        this.allEntityService.set('ibz5sample0010', () => import('@/service/ibz5-sample0010/ibz5-sample0010-service'));
        this.allEntityService.set('ibz5sample0006', () => import('@/service/ibz5-sample0006/ibz5-sample0006-service'));
        this.allEntityService.set('ibz5sample0020', () => import('@/service/ibz5-sample0020/ibz5-sample0020-service'));
        this.allEntityService.set('ibz5sample0003', () => import('@/service/ibz5-sample0003/ibz5-sample0003-service'));
        this.allEntityService.set('ibz5sample0007', () => import('@/service/ibz5-sample0007/ibz5-sample0007-service'));
        this.allEntityService.set('ibz5softwaresuit', () => import('@/service/ibz5-software-suit/ibz5-software-suit-service'));
        this.allEntityService.set('ibz5sample0016', () => import('@/service/ibz5-sample0016/ibz5-sample0016-service'));
        this.allEntityService.set('ibz5customer_intf', () => import('@/service/ibz5-customer-intf/ibz5-customer-intf-service'));
        this.allEntityService.set('ibz5sample0002', () => import('@/service/ibz5-sample0002/ibz5-sample0002-service'));
        this.allEntityService.set('ibz5sample0008', () => import('@/service/ibz5-sample0008/ibz5-sample0008-service'));
        this.allEntityService.set('ibz5account', () => import('@/service/ibz5-account/ibz5-account-service'));
        this.allEntityService.set('ibz5sample0014', () => import('@/service/ibz5-sample0014/ibz5-sample0014-service'));
        this.allEntityService.set('ibz5ordertype', () => import('@/service/ibz5-order-type/ibz5-order-type-service'));
        this.allEntityService.set('ibz5uniproduct', () => import('@/service/ibz5-uniproduct/ibz5-uniproduct-service'));
        this.allEntityService.set('ibz5sample0019', () => import('@/service/ibz5-sample0019/ibz5-sample0019-service'));
        this.allEntityService.set('ibz5sample0015', () => import('@/service/ibz5-sample0015/ibz5-sample0015-service'));
        this.allEntityService.set('ibz5sample0004', () => import('@/service/ibz5-sample0004/ibz5-sample0004-service'));
        this.allEntityService.set('ibz5sample0011', () => import('@/service/ibz5-sample0011/ibz5-sample0011-service'));
        this.allEntityService.set('ibz5customermg', () => import('@/service/ibz5-customer-mg/ibz5-customer-mg-service'));
        this.allEntityService.set('ibz5customer', () => import('@/service/ibz5-customer/ibz5-customer-service'));
        this.allEntityService.set('ibz5sample0017', () => import('@/service/ibz5-sample0017/ibz5-sample0017-service'));
        this.allEntityService.set('ibz5cpu', () => import('@/service/ibz5-cpu/ibz5-cpu-service'));
        this.allEntityService.set('ibz5sample0009', () => import('@/service/ibz5-sample0009/ibz5-sample0009-service'));
        this.allEntityService.set('ibz5sample0012', () => import('@/service/ibz5-sample0012/ibz5-sample0012-service'));
        this.allEntityService.set('ibz5order', () => import('@/service/ibz5-order/ibz5-order-service'));
    }

    /**
     * 加载实体数据服务
     *
     * @protected
     * @param {string} serviceName
     * @returns {Promise<any>}
     * @memberof EntityServiceRegister
     */
    protected async loadService(serviceName: string): Promise<any> {
        const service = this.allEntityService.get(serviceName);
        if (service) {
            return service();
        }
    }

    /**
     * 获取应用实体数据服务
     *
     * @param {string} name
     * @returns {Promise<any>}
     * @memberof EntityServiceRegister
     */
    public async getService(name: string): Promise<any> {
        if (this.serviceCache.has(name)) {
            return this.serviceCache.get(name);
        }
        const entityService: any = await this.loadService(name);
        if (entityService && entityService.default) {
            const instance: any = new entityService.default();
            this.serviceCache.set(name, instance);
            return instance;
        }
    }

}
export const entityServiceRegister: EntityServiceRegister = new EntityServiceRegister();