import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 订单服务对象基类
 *
 * @export
 * @class IBZ5OrderServiceBase
 * @extends {EntityServie}
 */
export default class IBZ5OrderServiceBase extends EntityService {

    /**
     * Creates an instance of  IBZ5OrderServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  IBZ5OrderServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof IBZ5OrderServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='ibz5order';
        this.APPDEKEY = 'ibz5orderid';
        this.APPDENAME = 'ibz5orders';
        this.APPDETEXT = 'ibz5ordername';
        this.APPNAME = 'demo';
        this.SYSTEMNAME = 'demosys';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/ibz5orders/${context.ibz5order}/select`,data,isloading);

            return res;
    }

    /**
     * SelectTemp接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async SelectTemp(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/ibz5orders/${context.ibz5order}/selecttemp`,data,isloading);
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/ibz5orders`,data,isloading);
        
        return res;
    }

    /**
     * CreateTemp接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async CreateTemp(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/ibz5orders/${context.ibz5order}/createtemp`,data,isloading);
            return res;
    }

    /**
     * CreateTempMajor接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async CreateTempMajor(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/ibz5orders/${context.ibz5order}/createtempmajor`,data,isloading);
            return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/ibz5orders/${context.ibz5order}`,data,isloading);
            
            return res;
    }

    /**
     * UpdateTemp接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async UpdateTemp(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().put(`/ibz5orders/${context.ibz5order}/updatetemp`,data,isloading);
            return res;
    }

    /**
     * UpdateTempMajor接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async UpdateTempMajor(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().put(`/ibz5orders/${context.ibz5order}/updatetempmajor`,data,isloading);
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().delete(`/ibz5orders/${context.ibz5order}`,isloading);
            return res;
    }

    /**
     * RemoveTemp接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async RemoveTemp(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().delete(`/ibz5orders/${context.ibz5order}/removetemp`,isloading);
            return res;
    }

    /**
     * RemoveTempMajor接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async RemoveTempMajor(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().delete(`/ibz5orders/${context.ibz5order}/removetempmajor`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/ibz5orders/${context.ibz5order}`,isloading);
            
            return res;
    }

    /**
     * GetTemp接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async GetTemp(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/ibz5orders/${context.ibz5order}/gettemp`,isloading);
            
            return res;
    }

    /**
     * GetTempMajor接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async GetTempMajor(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/ibz5orders/${context.ibz5order}/gettempmajor`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/ibz5orders/getdraft`,isloading);
        res.data.ibz5order = data.ibz5order;
        
        return res;
    }

    /**
     * GetDraftTemp接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async GetDraftTemp(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/ibz5orders/getdrafttemp`,isloading);
        res.data.ibz5order = data.ibz5order;
        
        return res;
    }

    /**
     * GetDraftTempMajor接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async GetDraftTempMajor(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/ibz5orders/${context.ibz5order}/getdrafttempmajor`,isloading);
            
            return res;
    }

    /**
     * BUIAction接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async BUIAction(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/ibz5orders/${context.ibz5order}/buiaction`,data,isloading);
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/ibz5orders/${context.ibz5order}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/ibz5orders/${context.ibz5order}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchCSDY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchCSDY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchcsdy`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempCSDY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempCSDY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempcsdy`,data,isloading);
        return res;
    }

    /**
     * FetchCurState30接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchCurState30(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchcurstate30`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempCurState30接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempCurState30(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempcurstate30`,data,isloading);
        return res;
    }

    /**
     * FetchDDJETJBB接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchDDJETJBB(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchddjetjbb`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempDDJETJBB接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempDDJETJBB(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempddjetjbb`,data,isloading);
        return res;
    }

    /**
     * FetchDDReport接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchDDReport(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchddreport`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempDDReport接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempDDReport(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempddreport`,data,isloading);
        return res;
    }

    /**
     * FetchDYDDMXSJY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchDYDDMXSJY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchdyddmxsjy`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempDYDDMXSJY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempDYDDMXSJY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempdyddmxsjy`,data,isloading);
        return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchdefault`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempdefault`,data,isloading);
        return res;
    }

    /**
     * FetchEchartsDefaultDataSource接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchEchartsDefaultDataSource(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchechartsdefaultdatasource`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempEchartsDefaultDataSource接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempEchartsDefaultDataSource(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempechartsdefaultdatasource`,data,isloading);
        return res;
    }

    /**
     * FetchGaugeDataSource接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchGaugeDataSource(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchgaugedatasource`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempGaugeDataSource接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempGaugeDataSource(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempgaugedatasource`,data,isloading);
        return res;
    }

    /**
     * FetchGaugeDataSourceByTime接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchGaugeDataSourceByTime(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchgaugedatasourcebytime`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempGaugeDataSourceByTime接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempGaugeDataSourceByTime(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempgaugedatasourcebytime`,data,isloading);
        return res;
    }

    /**
     * FetchLOGIC_22接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchLOGIC_22(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchlogic_22`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempLOGIC_22接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempLOGIC_22(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtemplogic_22`,data,isloading);
        return res;
    }

    /**
     * FetchRadarDataSource接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchRadarDataSource(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchradardatasource`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempRadarDataSource接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempRadarDataSource(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempradardatasource`,data,isloading);
        return res;
    }

    /**
     * FetchSHZOrder接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchSHZOrder(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchshzorder`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempSHZOrder接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempSHZOrder(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempshzorder`,data,isloading);
        return res;
    }

    /**
     * FetchState10接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchState10(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchstate10`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempState10接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempState10(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempstate10`,data,isloading);
        return res;
    }

    /**
     * FetchState30接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchState30(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchstate30`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempState30接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempState30(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempstate30`,data,isloading);
        return res;
    }

    /**
     * FetchState40接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchState40(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchstate40`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempState40接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempState40(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempstate40`,data,isloading);
        return res;
    }

    /**
     * FetchXECX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchXECX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/ibz5orders/fetchxecx`,tempData,isloading);
        return res;
    }

    /**
     * FetchTempXECX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZ5OrderServiceBase
     */
    public async FetchTempXECX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any =  Http.getInstance().get(`/ibz5orders/fetchtempxecx`,data,isloading);
        return res;
    }
}